==> Mapster-1.4.3.zip: Mapster/Locale/esES.lua <==
-- Mapster Locale
-- Please use the Localization App on WoWAce to Update this
-- http://www.wowace.com/projects/mapster/localization/ ;¶

local L = LibStub("AceLocale-3.0"):NewLocale("Mapster", "esES")
if not L then return end

L["(Mini) Disable Mouse"] = "(Mini) Deshabilitar Ratón"
L["(Mini) Hide Border"] = "(Mini) Ocultar Borde"
L["Accuracy"] = "Precisión"
L["Adjust the size of the Player Arrow on the Map for better visibility."] = "Ajusta el tamaño de la Flecha del Jugador en el mapa para mejorar su visibilidad."
L["Alpha"] = "Alfa"
L["BattleMap"] = "Mapa de Batalla"
L["Battlegrounds"] = "Campos de Batalla"
-- L["Blobs & Panels"] = "Blobs & Panels"
-- L["Burning Crusade Instances"] = "Burning Crusade Instances"
-- L["Burning Crusade Raids"] = "Burning Crusade Raids"
-- L["Cataclysm Instances"] = "Cataclysm Instances"
-- L["Cataclysm Raids"] = "Cataclysm Raids"
-- L["Change the scale of the world map if you do not want the whole screen filled while the map is open."] = "Change the scale of the world map if you do not want the whole screen filled while the map is open."
-- L["Classic Instances"] = "Classic Instances"
-- L["Classic Raids"] = "Classic Raids"
L["Coordinates"] = "Coordenadas"
L["Cursor"] = "Cursor"
L["Debug"] = "Depurar"
L["Disable Mouse"] = "Deshabilitar Ratón"
-- L["Disable the mouse interactivity of the main map when in minimized mode, eg. to change zones."] = "Disable the mouse interactivity of the main map when in minimized mode, eg. to change zones."
-- L["Disable the mouse interactivity of the main map, eg. to change zones."] = "Disable the mouse interactivity of the main map, eg. to change zones."
L["Enable BattleMap"] = "Habilitar Mapa de Batalla"
L["Enable Coordinates"] = "Habilitar Coordenadas"
L["Enable FogClear"] = "Habilitar Mapa Descubierto"
L["Enable Group Icons"] = "Habilitar Iconos de Grupo"
L["Enable Instance Maps"] = "Activar Mapas de Instancias"
L["FogClear"] = "BorrarNiebla"
-- L["FogClear collects new Data in your own SavedVariables, but that data might get corrupted (or simply old) with a new patch. Reset the data if you see corruption in the world map."] = "FogClear collects new Data in your own SavedVariables, but that data might get corrupted (or simply old) with a new patch. Reset the data if you see corruption in the world map."
L["Group Icons"] = "Iconos Grupo"
L["Hide Border"] = "Ocultar Borde"
-- L["Hide Completely"] = "Hide Completely"
L["Hide Map Button"] = "Ocultar Botón del Mapa"
L["Hide Textures"] = "Ocultar Texturas"
-- L["Hide the borders of the big map."] = "Hide the borders of the big map."
-- L["Hide the borders of the minimized map."] = "Hide the borders of the minimized map."
-- L["Hide the surrounding textures around the BattleMap, only leaving you with the pure map overlays."] = "Hide the surrounding textures around the BattleMap, only leaving you with the pure map overlays."
L["Instance Maps"] = "Mapas de Instancias"
L["Mapster allows you to control various aspects of your World Map. You can change the style of the map, control the plugins that extend the map with new functionality, and configure different profiles for every of your characters."] = "Mapster permite controlar varios aspectos de tu Mapa del Mundo. Puedes cambiar el estilo de el mapa, controlar accesorios que amplían el mapa con nuevas funcionalidades, y configurar diferentes perfiles para cada uno de tus personajes."
-- L["Minimized Alpha"] = "Minimized Alpha"
-- L["Minimized Scale"] = "Minimized Scale"
L["Note: You need to reload your UI after reseting the data!"] = "Nota: ¡Necesitas recargar tu interfaz después de resetear los datos!"
-- L["Only WorldMap Blobs"] = "Only WorldMap Blobs"
L["Overlay Color"] = "Superposición de Color"
-- L["POI Scale"] = "POI Scale"
L["Player"] = "Jugador"
L["PlayerArrow Scale"] = "Tamaño de la Flecha del Jugador"
-- L["Quest Objectives"] = "Quest Objectives"
L["Reset FogClear Data"] = "Borrar Niebla Perdí los datos de"
L["Scale"] = "Tamaño"
-- L["Scale of the POI Icons on the Map."] = "Scale of the POI Icons on the Map."
-- L["Scale of the big map."] = "Scale of the big map."
-- L["Scale of the minimized map."] = "Scale of the minimized map."
-- L["Size on the Battle Map"] = "Size on the Battle Map"
-- L["Size on the World Map"] = "Size on the World Map"
-- L["The BattleMap module allows you to change the style of the BattlefieldMinimap, removing unnecessary textures or PvP Objectives."] = "The BattleMap module allows you to change the style of the BattlefieldMinimap, removing unnecessary textures or PvP Objectives."
-- L["The Coordinates module adds a display of your current location, and the coordinates of your mouse cursor to the World Map frame."] = "The Coordinates module adds a display of your current location, and the coordinates of your mouse cursor to the World Map frame."
-- L["The FogClear module removes the Fog of War from the World map, thus displaying the artwork for all the undiscovered zones, optionally with a color overlay on undiscovered areas."] = "The FogClear module removes the Fog of War from the World map, thus displaying the artwork for all the undiscovered zones, optionally with a color overlay on undiscovered areas."
-- L["The Group Icons module allows you to resize the raid and party icons on the world map."] = "The Group Icons module allows you to resize the raid and party icons on the world map."
L["The Instance Maps module allows you to view the Instance and Battleground Maps provided by the game without being in the instance yourself."] = "El módulo de Mapas de Instancias te permite ver los mapas de Instancias y Campos de Batalla proporcionados por el juego sin estar dentro de la Instancia o el Campo de Batalla."
-- L["The transparency of the big map."] = "The transparency of the big map."
-- L["The transparency of the minimized map."] = "The transparency of the minimized map."
-- L["Turn on debugging for the FogClear Module."] = "Turn on debugging for the FogClear Module."
-- L["Wrath Instances"] = "Wrath Instances"
-- L["Wrath Raids"] = "Wrath Raids"
L["You can change the transparency of the world map to allow you to continue seeing the world environment while your map is open for navigation."] = "Puedes cambiar la transparencia del mapa del mundo para poder seguir viendo el entorno aunque el mapa esté abierto."
-- L["You can control the accuracy of the coordinates, e.g. if you need very exact coordinates you can set this to 2."] = "You can control the accuracy of the coordinates, e.g. if you need very exact coordinates you can set this to 2."

==> Mapster-1.5.6.1.zip: Mapster/Locale/esES.lua <==
-- Mapster Locale
-- Please use the Localization App on WoWAce to Update this
-- http://www.wowace.com/projects/mapster/localization/ ;¶

local L = LibStub("AceLocale-3.0"):NewLocale("Mapster", "esES")
if not L then return end

L["Accuracy"] = "Precisión"
L["Adjust the size of the Player Arrow on the Map for better visibility."] = "Ajusta el tamaño de la Flecha del Jugador en el mapa para mejorar su visibilidad."
L["Alpha"] = "Alfa"
L["Battlegrounds"] = "Campos de Batalla"
L["BattleMap"] = "Mapa de Batalla"
-- L["Blobs & Panels"] = "Blobs & Panels"
-- L["Burning Crusade Instances"] = "Burning Crusade Instances"
-- L["Burning Crusade Raids"] = "Burning Crusade Raids"
-- L["Cataclysm Instances"] = "Cataclysm Instances"
-- L["Cataclysm Raids"] = "Cataclysm Raids"
-- L["Change the scale of the world map if you do not want the whole screen filled while the map is open."] = "Change the scale of the world map if you do not want the whole screen filled while the map is open."
-- L["Classic Instances"] = "Classic Instances"
-- L["Classic Raids"] = "Classic Raids"
L["Coordinates"] = "Coordenadas"
L["Cursor"] = "Cursor"
L["Debug"] = "Depurar"
L["Disable Mouse"] = "Deshabilitar Ratón"
-- L["Disable the mouse interactivity of the main map, eg. to change zones."] = "Disable the mouse interactivity of the main map, eg. to change zones."
-- L["Disable the mouse interactivity of the main map when in minimized mode, eg. to change zones."] = "Disable the mouse interactivity of the main map when in minimized mode, eg. to change zones."
-- L["EJ Icon Scale"] = "EJ Icon Scale"
L["Enable BattleMap"] = "Habilitar Mapa de Batalla"
L["Enable Coordinates"] = "Habilitar Coordenadas"
L["Enable FogClear"] = "Habilitar Mapa Descubierto"
L["Enable Group Icons"] = "Habilitar Iconos de Grupo"
L["Enable Instance Maps"] = "Activar Mapas de Instancias"
L["FogClear"] = "BorrarNiebla"
-- L["FogClear collects new Data in your own SavedVariables, but that data might get corrupted (or simply old) with a new patch. Reset the data if you see corruption in the world map."] = "FogClear collects new Data in your own SavedVariables, but that data might get corrupted (or simply old) with a new patch. Reset the data if you see corruption in the world map."
L["Group Icons"] = "Iconos Grupo"
L["Hide Border"] = "Ocultar Borde"
-- L["Hide Completely"] = "Hide Completely"
L["Hide Map Button"] = "Ocultar Botón del Mapa"
-- L["Hide Quest Panels"] = "Hide Quest Panels"
L["Hide Textures"] = "Ocultar Texturas"
-- L["Hide the borders of the big map."] = "Hide the borders of the big map."
-- L["Hide the borders of the minimized map."] = "Hide the borders of the minimized map."
-- L["Hide the surrounding textures around the BattleMap, only leaving you with the pure map overlays."] = "Hide the surrounding textures around the BattleMap, only leaving you with the pure map overlays."
L["Instance Maps"] = "Mapas de Instancias"
L["Mapster allows you to control various aspects of your World Map. You can change the style of the map, control the plugins that extend the map with new functionality, and configure different profiles for every of your characters."] = "Mapster permite controlar varios aspectos de tu Mapa del Mundo. Puedes cambiar el estilo de el mapa, controlar accesorios que amplían el mapa con nuevas funcionalidades, y configurar diferentes perfiles para cada uno de tus personajes."
L["(Mini) Disable Mouse"] = "(Mini) Deshabilitar Ratón"
L["(Mini) Hide Border"] = "(Mini) Ocultar Borde"
-- L["Minimized Alpha"] = "Minimized Alpha"
-- L["Minimized Scale"] = "Minimized Scale"
L["Note: You need to reload your UI after reseting the data!"] = "Nota: ¡Necesitas recargar tu interfaz después de resetear los datos!"
-- L["Only WorldMap Blobs"] = "Only WorldMap Blobs"
L["Overlay Color"] = "Superposición de Color"
-- L["Pandaria Instances"] = "Pandaria Instances"
-- L["Pandaria Raids"] = "Pandaria Raids"
L["Player"] = "Jugador"
L["PlayerArrow Scale"] = "Tamaño de la Flecha del Jugador"
-- L["POI Scale"] = "POI Scale"
L["Reset FogClear Data"] = "Borrar Niebla Perdí los datos de"
L["Scale"] = "Tamaño"
-- L["Scale of the big map."] = "Scale of the big map."
-- L["Scale of the Encounter Journal Icons on the Map."] = "Scale of the Encounter Journal Icons on the Map."
-- L["Scale of the minimized map."] = "Scale of the minimized map."
-- L["Scale of the POI Icons on the Map."] = "Scale of the POI Icons on the Map."
-- L["Size on the Battle Map"] = "Size on the Battle Map"
-- L["Size on the World Map"] = "Size on the World Map"
-- L["The BattleMap module allows you to change the style of the BattlefieldMinimap, removing unnecessary textures or PvP Objectives."] = "The BattleMap module allows you to change the style of the BattlefieldMinimap, removing unnecessary textures or PvP Objectives."
-- L["The Coordinates module adds a display of your current location, and the coordinates of your mouse cursor to the World Map frame."] = "The Coordinates module adds a display of your current location, and the coordinates of your mouse cursor to the World Map frame."
-- L["The FogClear module removes the Fog of War from the World map, thus displaying the artwork for all the undiscovered zones, optionally with a color overlay on undiscovered areas."] = "The FogClear module removes the Fog of War from the World map, thus displaying the artwork for all the undiscovered zones, optionally with a color overlay on undiscovered areas."
-- L["The Group Icons module allows you to resize the raid and party icons on the world map."] = "The Group Icons module allows you to resize the raid and party icons on the world map."
L["The Instance Maps module allows you to view the Instance and Battleground Maps provided by the game without being in the instance yourself."] = "El módulo de Mapas de Instancias te permite ver los mapas de Instancias y Campos de Batalla proporcionados por el juego sin estar dentro de la Instancia o el Campo de Batalla."
-- L["The transparency of the big map."] = "The transparency of the big map."
-- L["The transparency of the minimized map."] = "The transparency of the minimized map."
-- L["Turn on debugging for the FogClear Module."] = "Turn on debugging for the FogClear Module."
-- L["Wrath Instances"] = "Wrath Instances"
-- L["Wrath Raids"] = "Wrath Raids"
L["You can change the transparency of the world map to allow you to continue seeing the world environment while your map is open for navigation."] = "Puedes cambiar la transparencia del mapa del mundo para poder seguir viendo el entorno aunque el mapa esté abierto."
-- L["You can control the accuracy of the coordinates, e.g. if you need very exact coordinates you can set this to 2."] = "You can control the accuracy of the coordinates, e.g. if you need very exact coordinates you can set this to 2."
